import { onMount } from "solid-js";
import L from 'leaflet';
import Embalse from "../interfaces/Embalse";
import Api from "../helpers/Api";
import { useNavigate } from "@solidjs/router";
import Navbar from "../partials/Navbar";

function Viewer() {
  const navigate = useNavigate();
  let map: L.Map;

  let embalses: Embalse[] = [];

  onMount(() => {
    map = L.map('map');
    L.tileLayer('https://tile.openstreetmap.org/{z}/{x}/{y}.png', {
      maxZoom: 19,
      attribution: '&copy; <a href="http://www.openstreetmap.org/copyright">OpenStreetMap</a>'
    }).addTo(map);

    getEmbalses();
  });

  const getEmbalses = async () => {
    embalses = await Api.embalses();

    embalses.forEach(c => {
      L.marker([parseFloat(c.x), parseFloat(c.y)]).on('click', () => navigate('/embalses/' + c.id)).addTo(map);
    });
  }

  return (
    <>
      <Navbar />
      <div class="container has-text-centered">
        <div id="map" style={{
          height: '70vh'
        }}></div>
      </div>
    </>
  );
}

export default Viewer;
